@@ -4,4 +4,4 @@ from .iplot import iplot_location, iplot_timeseries
 from .md5 import md5
 from .es_create_indexes import es_create_indexes
 from .emso import EMSO
-from .md_widgets import widget_qc, widget_emso
+from .md_widgets import widget_qc, widget_emso, widget_emso_qc, widget_save
